@@ -1,7 +1,7 @@
 dispMUA.arDispMUAAllocation["g"] =
 {
   "gp software directory opus" : [ "gp_opus.png" ] ,
-  "gimp useless mail program" : [ "gimp.png" ] ,
+  "gimp useless mail program" : [ "gimp.png" , "http://www.gimp.org/" ] ,
   "goto software sarbacane" : [ "sarbacane.png" ] ,
   "guweb mailing system" : [ "guweb_wonderbook.png" ] ,
   "grono mailing system" : [ "grono.png" ] ,
@@ -12,6 +12,8 @@ dispMUA.arDispMUAAllocation["g"] =
   "genesys e-mail" : [ "genesys7.png" ] ,
   "group-office" : [ "group_office.png" ] ,
   "groundspeak" : [ "groundspeak.png" ] ,
+  "govdelivery" : [ "govdelivery.png" , "http://www.govdelivery.com/" ] ,
+  "getresponse" : [ "getresponse.png" , "http://www.getresponse.com/" ] ,
   "goowy mail" : [ "goowy_mail.png" , "http://www.goowy.com/" ] ,
   "gandi mail" : [ "gandi_mail.png" ] ,
   "gatormail" : [ "gatormail.png" , "http://sourceforge.net/projects/gatormail/" ] ,
@@ -24,6 +26,7 @@ dispMUA.arDispMUAAllocation["g"] =
   "genexus" : [ "genexus.png" , "http://www.genexus.com/" ] ,
   "gemini/" : [ "gemini.png" ] ,
   "geeklog" : [ "geeklog.png" ] ,
+  "galette" : [ "galette.png" , "http://galette.tuxfamily.org/" ] ,
   "gnarwl" : [ "gnarwl.png" , "http://www.home.unix-ag.org/patrick/index.php?gnarwl" ] ,
   "gemida" : [ "gemida_de.png" , "http://www.gemida.de/" ] ,
   "gcmail" : [ "gcmail.png" , "http://www.gcmail.de/" ] ,
