@@ -6,9 +6,11 @@ dispMUA.arDispMUAAllocation["j"] =
   "jobserve-xss" : [ "jobserve.png" , "http://www.jobserve.com/" ] ,
   "jana-server" : [ "jana.png" ] ,
   "jonapot.hu" : [ "netfactory_hu.png" , "http://www.netfactory.hu/" ] ,
+  "jobletter " : [ "jobanzeiger.png" , "http://www.jobanzeiger.de/" ] ,
   "jpvmailer" : [ "jpvmailer.png" , "http://www.ottorey.com.ar/jpvmailer.htm" ] ,
   "jaw::mail" : [ "jawmail.png" , "http://www.jawmail.org/" ] ,
-  "javamail" : [ "java.png" ] ,
+  "jet.mail" : [ "jet-mail.png" , "http://www.jetmail.pl/" ] ,
+  "javamail" : [ "java.png" , "http://java.sun.com/products/javamail/" ] ,
   "jsvmail" : [ "shuriken_pro.png" ] ,
   "jawmail" : [ "jawmail.png" , "http://www.jawmail.org/" ] ,
   "jamaila" : [ "jamaila.png" , "http://www.javakaffee.de/jamaila/" ] ,
