@@ -2,9 +2,11 @@ dispMUA.arDispMUAAllocation["k"] =
 {
   "kayako supportsuite" : [ "kayako.png" ] ,
   "kerio mailserver" : [ "kerio.png" ] ,
+  "kochmeister.com" : [ "kochmeister.png" , "http://www.kochmeister.com/" ] ,
   "kayako esupport" : [ "kayako.png" ] ,
   "kaufman pravda" : [ "kaufman_pravda.png" , "http://www.kaufmansoft.com/" ] ,
   "karen's mailer" : [ "karensmailer.png" ] ,
+  "kontur-extern" : [ "kontur-extern.png" , "http://www.kontur-extern.ru/" ] ,
   "kienis mailer" : [ "kienis_mailer.png" ] ,
   "kerio outlook" : [ "kerio.png" ] ,
   "kana response" : [ "kana_response.png" ] ,
@@ -17,10 +19,10 @@ dispMUA.arDispMUAAllocation["k"] =
   "kaspersky" : [ "kaspersky.png" ] ,
   "katamail" : [ "katamail.png" ] ,
   "koomail" : [ "koomail.png" , "http://www.koomail.com/" ] ,
-  "ken! 3" : [ "ken3.png" ] ,
   "k-mail" : [ "k-mail.png" , "http://www.kcsoftwares.com/" ] ,
   "knode" : [ "knode.png" ] ,
   "knews" : [ "knews.png" ] ,
   "kmail" : [ "kmail.png" , "http://kontact.kde.org/kmail/" ] ,
+  "ken!" : [ "ken.png" , "http://www.avm.de/" ] ,
   "kana" : [ "kana.png" ] ,
 }
