@@ -9,7 +9,9 @@ dispMUA.arDispMUAAllocation["q"] =
   "quotient q.tools" : [ "quotient_qtools.png" , "http://www.quotientmarketing.com/qtools_defined.aspx" ] ,
   "quickmail pro" : [ "quickmail_pro.png" ] ,
   "qualisite cms" : [ "qualisite_de.png" , "http://www.qualisite.de/" ] ,
+  "qa webaccess" : [ "qaconsulting.png" , "http://www.qaconsulting.com.br/" ] ,
   "quickmail" : [ "quickmail.png" ] ,
+  "qps.qmail" : [ "python.png" , "http://pypi.python.org/pypi/QPS/" ] ,
   "qqmail" : [ "qqmail.png" ] ,
-  "qmail" : [ "qmail.png" ] ,
+  "qmail" : [ "qmail.png" , "http://www.qmail.org/" ] ,
 }
